import javax.imageio.*;
import java.awt.image.*;
import java.io.*;
import java.awt.Color;
import java.net.URL;

/**
 * A class to draw ASCII art and perform image manipulation.
 * 
 * @author Malcolm Ryan
 * @version 23 Aug 2012
 */
public class ASCIIArt
{
    /**
     * An array of the characters used to represent different brightness pixels from black to white
     */
    public static final char[] PIXEL_CHARS = {'X','8','o',':','.',' '}; // from black to white

    /**
     * This method takes a URL for an image and converts it to an array.
     * 
     * The image is returned as a width by height 2D array.
     * Each entry contains a brightness level from 0 (black) to (PIXEL_CHARS.length-1) (white)
     * 
     * @param url The URL to the image to load
     * @returns The image as a 2D array of brightness values
     */
    public int[][] readImage(String url) throws IOException
    {
        // fetch the image
        BufferedImage img = ImageIO.read(new URL(url));

        // create the array to match the dimensions of the image
        int width = img.getWidth();
        int height = img.getHeight();
        int[][] imageArray = new int[width][height];
        
        // convert the pixels of the image into brightness values
        for (int x = 0; x < width; x++)
        {
            for (int y = 0; y < height; y++)
            {
                // get the pixel at (x,y) 
                
                int rgb = img.getRGB(x,y);
                Color c = new Color(rgb);
                int red = c.getRed();
                int green = c.getGreen();
                int blue = c.getBlue();
                
                // convert to greyscale
                float[] hsb = Color.RGBtoHSB(red, green, blue, null);                
                int brightness = (int)Math.round(hsb[2] * (PIXEL_CHARS.length - 1));
                
                imageArray[x][y] = brightness;
            }
        }
        return imageArray;
    }
}
